import 'package:cpt_services/components/chooseAirConditionContent.dart';
import 'package:cpt_services/components/chooseAirConditionContent_vm.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/generated/l10n.dart';
import 'package:domain/entity/garage_sale_rent_entity.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:plugin_basic/provider/app_config/app_config_service.dart';
import 'package:router/componentRouter/component_service_manager.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/ext_dart.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/chooseHouseCleanContent.dart';
import '../../../components/chooseVisitTimeContent_vm.dart';
import '../../../constants_services.dart';
import '../../../router/page/services_page_router.dart';
import 'service_order_confirm_state.dart';
import 'service_order_confirm_vm.dart';
import '../../../components/status_card_item.dart';

@RoutePage()
class ServiceOrderConfirmPage extends HookConsumerWidget {
  final int id;
  final int serviceTypeCode;
  const ServiceOrderConfirmPage({
    Key? key,
    required this.id,
    required this.serviceTypeCode,
  }) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context, required int id, required int serviceTypeCode}) {
    if (context != null) {
      context.router.push(ServiceOrderConfirmPageRoute(id: id, serviceTypeCode: serviceTypeCode));
    } else {
      appRouter.push(ServiceOrderConfirmPageRoute(id:id, serviceTypeCode: serviceTypeCode));
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(serviceOrderConfirmVmProvider.notifier);
    final state = ref.watch(serviceOrderConfirmVmProvider);
    // final appConfigState = ref.watch(appConfigServiceProvider)

    final totalPrice = ref.watch(serviceOrderConfirmVmProvider.select((state) => state.totalPrice));

    useEffect(() {
      vm.setInitPageData(id: id, serviceTypeCode: serviceTypeCode);
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return () {
        // 组件卸载时执行
      };
    }, []);

    return Scaffold(
      appBar: MyAppBar.appBar(
        context,
        "Confirm Order",
        backgroundColor: context.appColors.whiteBG,
      ),
      backgroundColor: ColorUtils.string2Color("#F2F3F6"),
      body: SizedBox(
          width: double.infinity,
          height: double.infinity,
          child: EasyRefresh(
            key: ValueKey('ServiceOrderConfirm'),
            controller: vm.refreshController,
            // 上拉加载
            onLoad: null,
            // 下拉刷新
            onRefresh: null,
            child: LoadStateLayout(
              state: state.loadingState,
              errorMessage: state.errorMessage,
              errorRetry: () {
                vm.retryRequest();
              },
              successWidget: Column(
                  children: [
                    Expanded(child: _buildBody(state, vm, context,ref)),
                    // 底部联系信息
                    Visibility(
                      visible: state.loadingState == LoadState.State_Success,
                      child: state.datas !=null ? _buildBottomSection(state, vm,ref, context, id, serviceTypeCode, totalPrice): Container(),
                    )

                  ],
              ),
            ),
          ).marginOnly(left: 0,right: 0,top: 0,bottom: 0)
      ),
    );
  }

  Widget _buildBody(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context, WidgetRef ref) {
    return SingleChildScrollView(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          // 评分
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderScore(state, vm, context),
          ),
          // profile信息
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderProfile(state, vm, context),
          ),
          // 订单 服务项目
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderService(state, vm, context),
          ),
          // 订单 上门时间
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderVisitTime(state, vm, context).onTap((){
              vm.handlerClickVisitTime(context);
            }),
          ),
          // 订单 card 信息
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderPayCardInfo(state, vm, context),
          ),

          // 订单备注
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderRemark(state, vm, context, ref),
          ),
          // 订单 rules
          Container(
            color: context.appColors.whiteBG,
            width: double.infinity,
            margin: const EdgeInsets.only(left: 0, right: 0, top: 5, bottom: 0),
            padding: const EdgeInsets.only(left: 10, right: 10, top: 18.5, bottom: 18.5),
            child: _buildOrderRules(state, vm, context),
          ),
        ],
      ),
    );
  }

  Widget _buildOrderScore(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    double score = 5.0;
    //  评分
    return Column(
      children: [
        Container(
          width: double.infinity,
          color: context.appColors.whiteBG,
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              MyTextView(
                "House Cleaning Services",
                textColor: context.appColors.textBlack,
                fontSize: 18,
                isFontBold: true,
                marginBottom: 5,
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.start,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  AnimatedRatingStars(
                    initialRating: score,
                    onChanged: (rating) {
                    },
                    readOnly: true,
                    displayRatingValue: true, // Display the rating value
                    interactiveTooltips: true, // Allow toggling half-star state
                    customFilledIcon: Icons.star,
                    customHalfFilledIcon: Icons.star_half,
                    customEmptyIcon: Icons.star_border,
                    filledColor: ColorUtils.string2Color("#FF0000"),
                    starSize: 16.5,
                    animationDuration: const Duration(milliseconds: 0),
                    animationCurve: Curves.easeInOut,
                  ),
                  MyTextView(
                    "${score}",
                    textColor: context.appColors.textBlack,
                    fontSize: 16,
                    isFontMedium: true,
                    marginLeft: 15,
                  ),
                ],
              ),
              MyTextView(
                "HONG YE GROUP PTE LTD",
                textColor: context.appColors.textDarkGray999,
                fontSize: 12,
                isFontRegular: true,
                marginTop: 10,
                marginBottom: 5,
              ),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildOrderProfile(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const MyAssetImage(
              Assets.serviceLocationIcon,
              width: 15,
              height: 17.5,
            ),
            const SizedBox(
              width: 10,
            ),
            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                MyTextView(
                  '705 Qiming Huijin Building',
                  fontSize: 17,
                  isFontBold: true,
                  textColor: context.appColors.textBlack,
                  marginBottom: 5,
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: [
                    MyTextView(
                      'Sundy',
                      fontSize: 14,
                      textColor: context.appColors.textDarkGray999,
                      isFontRegular: true,
                    ),
                    MyTextView(
                      '+6588991122',
                      fontSize: 14,
                      textColor: context.appColors.textDarkGray999,
                      isFontRegular: true,
                      marginLeft: 10,
                    ),
                  ],
                ),
              ],
            ),
          ],
        ),
      ],
    );
  }

  Widget _buildOrderService(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    return Column(
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            const MyAssetImage(
              Assets.serviceServiceAvatorIcon,
              width: 15,
              height: 17.5,
            ),
            const SizedBox(
              width: 10,
            ),
            MyTextView(
              'Service',
              fontSize: 17,
              isFontBold: true,
              textColor: context.appColors.textBlack,
              marginBottom: 5,
            ),
          ],
        ),
        if (serviceTypeCode == servicesConstants.servicesType['houseCleaning']!['code'])
          // 室内清理
          _buildCleanContent(state, vm, context)
        else if (serviceTypeCode == servicesConstants.servicesType['airConditioner']!['code'])
          // 空调清理
          _buildCleanContent(state, vm, context)
        else
          const SizedBox.shrink(),
      ],
    );
  }

  Widget _buildCleanContent(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    final title = 'House Cleaning Services';
    final areaSizeRange = '1 Bedroom';
    final num =  1;
    final price = 0;
    bool isChecked = false;
    bool disabled = true;
    final isDisable = useState<bool>(disabled);

    return Container(
      padding: EdgeInsets.only(left: 10, right: 10, top: 10, bottom: 10),
      margin: EdgeInsets.only(left: 15, right: 15, top: 0, bottom: 0),
      color: ColorUtils.string2Color('#F8F8F8'),
      child: Column(
        children: [
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            mainAxisSize: MainAxisSize.max,
            children: [
              Expanded(
                child: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    MyTextView(
                      title,
                      fontSize: 16,
                      isFontMedium: true,
                      textColor: context.appColors.textBlack,
                    ),
                    MyTextView(
                      areaSizeRange,
                      fontSize: 15,
                      isFontRegular: true,
                      textColor: context.appColors.textDarkGray999,
                      marginTop: 5,
                    ),
                  ],
                ),
              ),
              // MyCartNum(onChange: (value){
              //   vm.handlerChangeNum(context, value, index);
              // })
              // MyButton(
              //   text: '\$$price',
              //   onPressed: (){
              //       // vm.handlerChangeNum(context, value, index);
              //   },
              //   fontSize: 19,
              //   fontWeight: FontWeight.w500,
              // )
              Container(
                child: MyButton(
                  text: '\$$price',
                  onPressed: null,
                  minWidth: 80,
                  minHeight: 40,
                  fontSize: 19,
                  fontWeight: FontWeight.w500,
                  // enable: !isDisable.value,
                  textColor:  context.appColors.textPrimary,
                  backgroundColor: context.appColors.textWhite,
                  disabledBackgroundColor: context.appColors.disEnableGray,
                  disabledTextColor: context.appColors.textWhite,
                ),
              ),
            ],
          ),
          // Divider(),
        ],
      ),
    );
  }


  Widget _buildOrderVisitTime(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.max,
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
      children: [
        Row(
          children: [
            const MyAssetImage(
              Assets.serviceTimeIcon,
              width: 16,
              height: 16,
            ),
            const SizedBox(
              width: 10,
            ),
            MyTextView(
              'Visit Time',
              fontSize: 17,
              isFontBold: true,
              textColor: context.appColors.textBlack,
            ),
          ],
        ),
        Expanded(
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.end,
            children: [
              MyTextView(
                '2021-01-01 12:00',
                fontSize: 15,
                textColor: context.appColors.textDarkGray999,
                isFontRegular: true,
                textAlign: TextAlign.end,
                marginRight: 17,
              ),
              // 右箭头 icon
              const MyAssetImage(
                Assets.serviceRightIcon,
                width: 17.5,
                height: 17.5,
              ),
            ],
          ),
        ),
      ],
    );
  }

  Widget _buildOrderPayCardInfo(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    return Container(
      width: double.infinity,
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: [
          MyTextView(
            'CARD',
            fontSize: 17,
            isFontMedium: true,
            textColor: context.appColors.textPrimary,
            marginBottom: 15,
          ),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              Wrap(
                alignment: WrapAlignment.start,
                crossAxisAlignment: WrapCrossAlignment.center,
                children: [
                  const MyAssetImage(
                    Assets.serviceCardIcon,
                    width: 63.5,
                    height: 38.5,
                  ),
                  MyTextView(
                    'Ending 9423',
                    fontSize: 15,
                    isFontMedium: true,
                    textColor: context.appColors.textBlack,
                    marginLeft: 27.5,
                  ),
                ],
              ),
              MyButton(
                onPressed: (){
                  ComponentServiceManager().paymentService.startChooseCardPage();
                },
                text: 'Change',
                minWidth: 80,
                minHeight: 30,
                textColor: context.appColors.textWhite,
                fontSize: 15,
                fontWeight: FontWeight.w400,
                backgroundColor: context.appColors.textPrimary,
              ),
            ],
          ),
        ],
      ),
    );
  }

  Widget _buildOrderRemark(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context, WidgetRef ref) {
    //签名的说明文本
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            // const MyAssetImage(
            //   Assets.assetsYyHomeLogo,
            //   width: 15,
            //   height: 17.5,
            // ),
            // const SizedBox(
            //   width: 10,
            // ),
            MyTextView(
              'Remarks Information',
              fontSize: 17,
              isFontBold: true,
              textColor: context.appColors.textBlack,
              marginBottom: 15,
            ),
          ],
        ),
        Container(
          margin: const EdgeInsets.only(left:10, right:10,top: 0),
          width: double.infinity,
          height: 200,
          padding: const EdgeInsets.all(15),
          decoration: BoxDecoration(
              color: ColorUtils.string2Color("#F2F3F6"),
              borderRadius: BorderRadius.circular(5),
              boxShadow: [
                BoxShadow(
                  color: Colors.grey.withOpacity(0.2),
                  spreadRadius:1,
                  blurRadius: 2,
                  offset: const Offset(0.5, 0.5), // changes position of shadow
                ),
              ]
          ),
          child: _buildTextAreaLayout(context, vm, ref, 'remark',),
        ),
      ],
    );
  }

  /// 多行输入框
  Widget _buildTextAreaLayout(BuildContext context, ServiceOrderConfirmVm vm, WidgetRef ref,String key){
    final state = ref.watch(serviceOrderConfirmVmProvider);
    final noteCount = useState(0);
    return Stack(
        children: [
          Container(
            child: TextField(
              cursorColor: context.appColors.authFiledText,
              cursorWidth: 1.5,
              autofocus: false,
              enabled: true,
              maxLines: null,
              focusNode: state.remarkInfo[key]!['focusNode'],
              controller: state.remarkInfo[key]!['controller'],
              decoration: InputDecoration(
                isDense: true,
                isCollapsed: true,
                border: InputBorder.none,
                hintText: state.remarkInfo[key]!['hintText'],
                hintStyle: TextStyle(
                  color: context.appColors.authFiledHint,
                  fontSize: 16.0,
                  fontWeight: FontWeight.w400,
                ),
              ),
              style: TextStyle(
                color: context.appColors.authFiledText,
                fontSize: 16.0,
                fontWeight: FontWeight.w400,
              ),
              textInputAction: TextInputAction.done,
              onSubmitted: (value) {
                FocusScope.of(context).unfocus();
              },
              expands: true,
              onChanged: (text) {
                // 当文本改变时，更新字符数量
                noteCount.value = text.length;
              },
            ),
          ),
          // Positioned(
          //   bottom: 0.0,
          //   right: 0.0,
          //   child: Text(
          //     S.current.characters(noteCount.value),
          //     style: TextStyle(
          //       color: context.appColors.textBlack,
          //       fontSize: 15.0,
          //     ),
          //   ),
          // ),
        ]
    );
  }


  Widget _buildOrderRules(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm, BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        Row(
          mainAxisAlignment: MainAxisAlignment.start,
          children: [
            MyTextView(
              'Service Rules',
              fontSize: 17,
              isFontBold: true,
              textColor: context.appColors.textBlack,
              marginBottom: 10,
            ),
          ],
        ),
        Column(
          mainAxisAlignment: MainAxisAlignment.start,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            MyTextView(
              'Dear user, in order to ensure the time efficiency of service personnel, if an order is cancelled within 60 minutes before the start of the service, a certain percentage of your order amount may be deducted. If a coupon is used for the order, it will be refunded to your account after cancellation. Please forgive me!If cancelled more than 60 minutes before the service, 100% of the payment amount will be refundedCancel within 0-60 minutes before the start of the service and the service personnel have accepted the order:If it is due to your personal reasons, the platform will deduct 20% of the payment amount (up to a maximum of 30 yuan), and the remaining amount will be refunded through the original payment methodIf it is due to the store\'s reasons, the platform will complete the verification within 24 hours. After verification is passed, the full amount will be refunded to the original route within 1-3 working daysAfter the service starts, if you have any disputes with the service personnel due to service quality issues, please contact customer service for resolution. Contact phone number: +65 66889955',
              fontSize: 14,
              textColor: context.appColors.textBlack,
              isFontRegular: true,
            ),
          ],
        )
      ],
    );
  }

  // 底部操作区域
  Widget _buildBottomSection(ServiceOrderConfirmState state, ServiceOrderConfirmVm vm,WidgetRef ref, BuildContext context, int id, int serviceTypeCode, totalPrice) {
    return Container(
      height: 50,
      width: double.infinity,
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        mainAxisSize: MainAxisSize.max,
        children: [
          Container(
            width: 122,
            child: Row(
              mainAxisAlignment: MainAxisAlignment.center,
              crossAxisAlignment: CrossAxisAlignment.center,
              mainAxisSize: MainAxisSize.max,
              children: [
                Container(
                  alignment: Alignment.center,
                  padding: const EdgeInsets.only(left:5, right: 0,top:5,bottom: 5),
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    mainAxisSize: MainAxisSize.max,
                    children: [
                      MyTextView(
                        "\$$totalPrice",
                        fontSize: 18,
                        textColor: Colors.white,
                        isFontRegular: true,
                        marginLeft: 5,
                        marginRight: 15,
                        onClick: (){

                        },
                      ),
                    ],
                  ),
                ),
              ],
            ).backgroundColor(context.appColors.textPrimary),
          ),
          Expanded(
            child: Container(
              color: context.appColors.redDefault,
              child: Center(
                child: MyTextView(
                  'Pay Now',
                  textColor: context.appColors.textWhite,
                  fontSize: 17,
                  isFontMedium: true,
                  textAlign: TextAlign.center,
                ),
              ),
            ).onTap((){
              vm.handlerClickPayNow(context, id: id , serviceTypeCode: serviceTypeCode);
            }),
          ),
        ],
      ),
    );
  }
}